@@ -1,25 +1,7 @@
- # Copyright (C) 2011, 2010, 2009 Oscar Perpiñán Lamigueiro
- #
- # This program is free software; you can redistribute it and/or
- # modify it under the terms of the GNU General Public License
- # as published by the Free Software Foundation; either version 2
- # of the License, or (at your option) any later version.
- #
- # This program is distributed in the hope that it will be useful,
- # but WITHOUT ANY WARRANTY; without even the implied warranty of
- # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- # GNU General Public License for more details.
- #
- # You should have received a copy of the GNU General Public License
- # along with this program; if not, write to the Free Software
- # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- #/
 optimShd<-function(lat,
                    modeTrk='fixed', 
                    modeRad='prom', 
                    dataRad,
-                   prev,
-                   prom, mapa, bd, 
                    sample='hour',
                    keep.night=TRUE,
                    sunGeometry='michalsky',
@@ -40,23 +22,7 @@ optimShd<-function(lat,
     warning('backtracking is only implemented for modeTrk=horiz')}
 
   ##Guardo argumentos de la función para utilizar después
-  if (!missing(mapa)){
-    dataRad=mapa
-    warning('Use of "mapa" argument is deprecated. You should use dataRad instead.')
-  }
-  if (!missing(prom)) {
-    dataRad=prom
-    warning('Use of "prom" argument is deprecated. You should use dataRad instead.')
-  }
-  if (!missing(bd)) {
-    dataRad=bd
-    warning('Use of "bd" argument is deprecated. You should use dataRad instead.')
-  }
-  if (!missing(prev)) {
-    dataRad=prev
-    warning('Use of "prev" argument is deprecated. You should use dataRad instead.')
-  }
-  ##if (missing(prev)) {prev=NULL}
+
   listArgs<-list(lat=lat, modeTrk=modeTrk, modeRad=modeRad,
                  dataRad=dataRad,
                  sample=sample, keep.night=keep.night,
